@@ -147,7 +147,7 @@ ThemeManager::ThemeManager(QSettings& settings, QWidget* parent)
 
 			QStringList sessions = QDir(Session::path(), "*.session").entryList(QDir::Files);
 			sessions.prepend(QString());
-			for (const QString& file : qAsConst(sessions)) {
+			for (const QString& file : std::as_const(sessions)) {
 				Session session(file);
 				if ((session.theme() == name) && (session.themeDefault() == false)) {
 					session.setTheme(id, false);
@@ -345,6 +345,7 @@ void ThemeManager::importTheme()
 	QSettings theme_ini(theme_filename, QSettings::IniFormat);
 	QString name = theme_ini.value("Name", QFileInfo(filename).completeBaseName()).toString();
 	{
+		theme_ini.setValue("Name", id);
 		const QStringList values = splitStringAtLastNumber(name);
 		int count = values.at(1).toInt();
 		while (Theme::exists(name)) {
