@@ -334,8 +334,8 @@
         <translation>Vierç Imagjine</translation>
     </message>
     <message>
-        <source>Images(%1)</source>
-        <translation>Imagjinis(%1)</translation>
+        <source>Images</source>
+        <translation>Imagjinis</translation>
     </message>
 </context>
 <context>
@@ -1854,4 +1854,11 @@
         <translation>Ctrl+Shift+`</translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Files to open in current session.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
